==> dart_native-0.3.16.tar.gz: lib/src/common/native_basic_type.dart <==
import 'dart:convert';

import 'package:dart_native/src/common/native_type_box.dart';

mixin _ToAlias {}

/// Stands for `char` in C.
// ignore: camel_case_types
class char extends NativeIntBox {
  const char(int raw) : super(raw);

  @override
  String toString() {
    return utf8.decode([raw]);
  }
}

/// Stands for `unsigned char` in C.
class unsigned_char = char with _ToAlias;

/// Stands for `byte` in Java.
class byte = NativeIntBox with _ToAlias;

/// Stands for `short` in C.
class short = NativeIntBox with _ToAlias;

/// Stands for `unsigned short` in C.
class unsigned_short = NativeIntBox with _ToAlias;

/// Stands for `unsigned int` in C.
class unsigned_int = NativeIntBox with _ToAlias;

/// Stands for `long` in C.
class long = NativeIntBox with _ToAlias;

/// Stands for `unsigned long` in C.
class unsigned_long = NativeIntBox with _ToAlias;

/// Stands for `long long` in C.
class long_long = NativeIntBox with _ToAlias;

/// Stands for `unsigned long long` in C.
class unsigned_long_long = NativeIntBox with _ToAlias;

/// Stands for `size_t` in C.
class size_t = NativeIntBox with _ToAlias;

/// Stands for `int8_t` in C.
class int8_t = NativeIntBox with _ToAlias;

/// Stands for `int16_t` in C.
class int16_t = NativeIntBox with _ToAlias;

/// Stands for `int32_t` in C.
class int32_t = NativeIntBox with _ToAlias;

/// Stands for `int64_t` in C.
class int64_t = NativeIntBox with _ToAlias;

/// Stands for `uint8_t` in C.
class uint8_t = NativeIntBox with _ToAlias;

/// Stands for `uint16_t` in C.
class uint16_t = NativeIntBox with _ToAlias;

/// Stands for `uint32_t` in C.
class uint32_t = NativeIntBox with _ToAlias;

/// Stands for `uint64_t` in C.
class uint64_t = NativeIntBox with _ToAlias;

/// Stands for `float` in C.
class float = NativeNumBox<double> with _ToAlias;

==> dart_native-0.4.0.tar.gz: lib/src/common/native_basic_type.dart <==
import 'dart:convert';

/// Stands for `char` in C.
// ignore: camel_case_types
typedef char = int;

extension utf8String on char {
  String toUTF8String() {
    return utf8.decode([this]);
  }
}

/// Stands for `unsigned char` in C.
// ignore: camel_case_types
typedef unsigned_char = char;

/// Stands for `unsigned short` in C.
// ignore: camel_case_types
typedef unsigned_short = int;

/// Stands for `unsigned int` in C.
// ignore: camel_case_types
typedef unsigned_int = int;

/// Stands for `unsigned long` in C.
// ignore: camel_case_types
typedef unsigned_long = int;

/// Stands for `long long` in C.
// ignore: camel_case_types
typedef long_long = int;

/// Stands for `unsigned long long` in C.
// ignore: camel_case_types
typedef unsigned_long_long = int;

/// Stands for `size_t` in C.
// ignore: camel_case_types
typedef size_t = int;

/// Stands for `int8_t` in C.
// ignore: camel_case_types
typedef int8_t = int;

/// Stands for `int16_t` in C.
// ignore: camel_case_types
typedef int16_t = int;

/// Stands for `int32_t` in C.
// ignore: camel_case_types
typedef int32_t = int;

/// Stands for `int64_t` in C.
// ignore: camel_case_types
typedef int64_t = int;

/// Stands for `uint8_t` in C.
// ignore: camel_case_types
typedef uint8_t = int;

/// Stands for `uint16_t` in C.
// ignore: camel_case_types
typedef uint16_t = int;

/// Stands for `uint32_t` in C.
// ignore: camel_case_types
typedef uint32_t = int;

/// Stands for `uint64_t` in C.
// ignore: camel_case_types
typedef uint64_t = int;
